@@ -24,12 +24,15 @@ def like_a_version(s):
 
 class Recipe(hexagonit.recipe.download.Recipe):
     def __init__(self, buildout, name, options):
-        # this copies configuration set in defaults.cfg to our options namespace
-        config_file = pkg_resources.resource_stream(__name__, "defaults.cfg")
-        config = ConfigParser.ConfigParser()
-        config.readfp(config_file)
-        for key, value in config.items("seleniumrc"):
-            options.setdefault(key, value)
+        if options.get('no-defaults') is None:
+            # Copy configuration set in defaults.cfg to our options namespace,
+            # but only if the user hasn't disabled it.
+            config_file = pkg_resources.resource_stream(__name__,
+                                                        "defaults.cfg")
+            config = ConfigParser.ConfigParser()
+            config.readfp(config_file)
+            for key, value in config.items("seleniumrc"):
+                options.setdefault(key, value)
 
         super(Recipe, self).__init__(buildout, name, options)
 
